"""
    Ory Oathkeeper API

    Documentation for all of Ory Oathkeeper's APIs.   # noqa: E501

    The version of the OpenAPI document: v0.38.20-beta.1
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_oathkeeper_client
from ory_oathkeeper_client.model.generic_error import GenericError


class TestGenericError(unittest.TestCase):
    """GenericError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGenericError(self):
        """Test GenericError"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GenericError()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
